@@ -280,24 +280,7 @@ class AirFreshT2017(Device):
         """Retrieve properties."""
 
         properties = AVAILABLE_PROPERTIES[self.model]
-
-        # A single request is limited to 16 properties. Therefore the
-        # properties are divided into multiple requests
-        _props = properties.copy()
-        values = []
-        while _props:
-            values.extend(self.send("get_prop", _props[:15]))
-            _props[:] = _props[15:]
-
-        properties_count = len(properties)
-        values_count = len(values)
-        if properties_count != values_count:
-            _LOGGER.debug(
-                "Count (%s) of requested properties does not match the "
-                "count (%s) of received values.",
-                properties_count,
-                values_count,
-            )
+        values = self.get_properties(properties, max_properties=15)
 
         return AirFreshStatus(defaultdict(lambda: None, zip(properties, values)))
 
