@@ -5,6 +5,7 @@ from typing import Any, Optional  # noqa: F401
 import click
 
 from .click_common import DeviceGroupMeta, LiteralParamType, command, format_output
+from .exceptions import DeviceInfoUnavailableException, PayloadDecodeException
 from .miioprotocol import MiIOProtocol
 
 _LOGGER = logging.getLogger(__name__)
@@ -120,10 +121,34 @@ class Device(metaclass=DeviceGroupMeta):
         self.token = token
         self._protocol = MiIOProtocol(ip, token, start_id, debug, lazy_discover)
 
-    def send(self, command: str, parameters: Any = None, retry_count=3) -> Any:
-        return self._protocol.send(command, parameters, retry_count)
+    def send(
+        self,
+        command: str,
+        parameters: Any = None,
+        retry_count=3,
+        *,
+        extra_parameters=None
+    ) -> Any:
+        """Send a command to the device.
+
+        Basic format of the request:
+        {"id": 1234, "method": command, "parameters": parameters}
+
+        `extra_parameters` allows passing elements to the top-level of the request.
+        This is necessary for some devices, such as gateway devices, which expect
+        the sub-device identifier to be on the top-level.
+
+        :param str command: Command to send
+        :param dict parameters: Parameters to send
+        :param int retry_count: How many times to retry on error
+        :param dict extra_parameters: Extra top-level parameters
+        """
+        return self._protocol.send(
+            command, parameters, retry_count, extra_parameters=extra_parameters
+        )
 
     def send_handshake(self):
+        """Send initial handshake to the device."""
         return self._protocol.send_handshake()
 
     @command(
@@ -137,7 +162,7 @@ class Device(metaclass=DeviceGroupMeta):
 
         :param str command: Command to send
         :param dict parameters: Parameters to send"""
-        return self._protocol.send(command, parameters)
+        return self.send(command, parameters)
 
     @command(
         default_output=format_output(
@@ -153,7 +178,12 @@ class Device(metaclass=DeviceGroupMeta):
         """Get miIO protocol information from the device.
         This includes information about connected wlan network,
         and hardware and software versions."""
-        return DeviceInfo(self._protocol.send("miIO.info"))
+        try:
+            return DeviceInfo(self.send("miIO.info"))
+        except PayloadDecodeException as ex:
+            raise DeviceInfoUnavailableException(
+                "Unable to request miIO.info from the device"
+            ) from ex
 
     def update(self, url: str, md5: str):
         """Start an OTA update."""
@@ -164,15 +194,15 @@ class Device(metaclass=DeviceGroupMeta):
             "file_md5": md5,
             "proc": "dnld install",
         }
-        return self._protocol.send("miIO.ota", payload)[0] == "ok"
+        return self.send("miIO.ota", payload)[0] == "ok"
 
     def update_progress(self) -> int:
         """Return current update progress [0-100]."""
-        return self._protocol.send("miIO.get_ota_progress")[0]
+        return self.send("miIO.get_ota_progress")[0]
 
     def update_state(self):
         """Return current update state."""
-        return UpdateState(self._protocol.send("miIO.get_ota_state")[0])
+        return UpdateState(self.send("miIO.get_ota_state")[0])
 
     def configure_wifi(self, ssid, password, uid=0, extra_params=None):
         """Configure the wifi settings."""
@@ -180,4 +210,37 @@ class Device(metaclass=DeviceGroupMeta):
             extra_params = {}
         params = {"ssid": ssid, "passwd": password, "uid": uid, **extra_params}
 
-        return self._protocol.send("miIO.config_router", params)[0]
+        return self.send("miIO.config_router", params)[0]
+
+    def get_properties(self, properties, *, max_properties=None):
+        """Request properties in slices based on given max_properties.
+
+        This is necessary as some devices have limitation on how many
+        properties can be queried at once.
+
+        If `max_properties` is None, all properties are requested at once.
+
+        :param list properties: List of properties to query from the device.
+        :param int max_properties: Number of properties that can be requested at once.
+        :return List of property values.
+        """
+        _props = properties.copy()
+        values = []
+        while _props:
+            values.extend(self.send("get_prop", _props[:max_properties]))
+            if max_properties is None:
+                break
+
+            _props[:] = _props[max_properties:]
+
+        properties_count = len(properties)
+        values_count = len(values)
+        if properties_count != values_count:
+            _LOGGER.debug(
+                "Count (%s) of requested properties does not match the "
+                "count (%s) of received values.",
+                properties_count,
+                values_count,
+            )
+
+        return values
